"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const npmlog_1 = __importDefault(require("npmlog"));
const taskId_1 = require("../task/taskId");
let _context;
function initialize(context) {
    _context = context;
}
exports.initialize = initialize;
function getPrefix(taskId) {
    const [pkg, task] = taskId_1.getPackageTaskFromId(taskId);
    return `${pkg} ${task}`;
}
function addToTaskLog(taskId, message) {
    var _a;
    const { taskLogs } = _context;
    if (!taskLogs.has(taskId)) {
        taskLogs.set(taskId, []);
    }
    (_a = taskLogs.get(taskId)) === null || _a === void 0 ? void 0 : _a.push(message);
}
function info(taskId, message, ...args) {
    addToTaskLog(taskId, message);
    return npmlog_1.default.info(getPrefix(taskId), message, ...args);
}
exports.info = info;
function warn(taskId, message, ...args) {
    addToTaskLog(taskId, message);
    return npmlog_1.default.warns(getPrefix(taskId), message, ...args);
}
exports.warn = warn;
function error(taskId, message, ...args) {
    addToTaskLog(taskId, message);
    return npmlog_1.default.error(getPrefix(taskId), message, ...args);
}
exports.error = error;
function verbose(taskId, message, ...args) {
    addToTaskLog(taskId, message);
    return npmlog_1.default.verbose(getPrefix(taskId), message, ...args);
}
exports.verbose = verbose;
exports.default = { info, warn, error, verbose };
